@@ -1,4 +1,5 @@
 import os
+import traceback
 from contextlib import contextmanager
 
 import distro
@@ -55,9 +56,6 @@ class Agent(agent.Agent):
 
     def add_traceable_filter(self):  #pylint:disable=R0201
         logger.debug("in add_traceable_filter")
-        if distro.id() == 'alpine':
-            logger.info('libtraceable unavailable on alpine linux, skipping filter registration')
-            return
         if self.is_lambda:
             logger.info('Not loading blocking extension - currently unsupported in lambda')
             return
@@ -72,5 +70,6 @@ class Agent(agent.Agent):
         try:
             Registry().register(Traceable)
             logger.debug("successfully initialized traceable filter")
-        except: # pylint:disable=W0702
+        except Exception as exc: # pylint:disable=W0703
+            logger.debug(''.join(traceback.format_exception(None, exc, exc.__traceback__)))
             logger.info("failed to register traceable filter")
